@@ -3,6 +3,7 @@
  * Daniel Nelson - 8/26/0
  *
  * Copyright (C) 2000  Daniel Nelson
+ * Copyright (C) 2004  Andrew Sayman
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +31,7 @@
 #include <GL/glut.h>
 
 #ifndef _WIN32
+#  include <GL/glext.h>
 #else
 #  include <glext.h>
 #endif
@@ -43,8 +45,11 @@
 #endif
 #endif
 
+#include <sys/time.h>
+
 using namespace std;
 
+#include "TextureLoader.h"
 #include "Game.h"
 #include "Displayer.h"
 #include "CelebrationManager.h"
@@ -53,7 +58,6 @@ using namespace std;
 #include "LightManager.h"
 #include "MetaState.h"
 #include "SparkleManager.h"
-#include "TextureLoader.h"
 #include "String.h"
 #include "ScoreRecordManager.h"
 #include "Score.h"
@@ -62,6 +66,7 @@ GLenum Displayer::rescale_method;
 bool Displayer::opengl_version_1_2;
 
 int Displayer::state;
+int Displayer::main_window;
 GLfloat Displayer::play_offset_y;
 
 #ifndef NO_MULTITEXTURING
@@ -76,12 +81,16 @@ PFNGLCLIENTACTIVETEXTUREARBPROC Displayer::glClientActiveTextureARB;
 GLint Displayer::screen_length;
 #endif
 
-void Displayer::initialize (   )
+void Displayer::initialize ( int width, int height  )
 {
   glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGBA | GLUT_DEPTH);
-  glutInitWindowSize(DC_WINDOW_PIXEL_STARTING_WIDTH,
-   DC_WINDOW_PIXEL_STARTING_HEIGHT);
-  glutCreateWindow(GC_NAME);
+  if (width != -1 && height != -1) {
+    glutInitWindowSize(width, height);
+  } else {
+    glutInitWindowSize(DC_WINDOW_PIXEL_STARTING_WIDTH,
+     DC_WINDOW_PIXEL_STARTING_HEIGHT);
+  }
+  main_window = glutCreateWindow(GC_NAME);
 
   state = 0;
 
@@ -201,6 +210,7 @@ void Displayer::gameFinish (   )
 
 void Displayer::cleanUp (   )
 {
+  glutDestroyWindow(main_window);
   for (int n = DC_NUMBER_USE_GARBAGE_TEX; n--; )
     if (garbage_texture_data[n] != null) {
       delete [] garbage_texture_data[n];
@@ -257,10 +267,12 @@ void Displayer::displayMeta (   )
 
   glDisable(GL_TEXTURE_2D);
 
-  glEnable(GL_LIGHTING);
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+    glEnable(GL_LIGHTING);
   glEnable(GL_COLOR_MATERIAL);
 
-  drawLevelLights();
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+    drawLevelLights();
 
   if (CelebrationManager::draw_game) {
 
@@ -294,7 +306,8 @@ void Displayer::displayMeta (   )
     Game::time_step = hold_time_step;
   }
 
-  glDisable(GL_LIGHTING);
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+    glDisable(GL_LIGHTING);
   glDisable(GL_COLOR_MATERIAL);
 
   glEnable(GL_BLEND);
@@ -304,11 +317,12 @@ void Displayer::displayMeta (   )
 
   glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_BLEND);
 
-  drawWinRecord();
-
-  // calls glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE)
-  // internally
-  drawCandy();
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS)) {
+    drawWinRecord();
+    // calls glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE)
+    // internally
+    drawCandy();
+  }
 
   drawScoreRecord();
 
@@ -326,10 +340,12 @@ void Displayer::displayPlay (   )
 
   glDisable(GL_TEXTURE_2D);
 
-  glEnable(GL_LIGHTING);
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+    glEnable(GL_LIGHTING);
   glEnable(GL_COLOR_MATERIAL);
 
-  drawLevelLights();
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+    drawLevelLights();
 
   if (!((Game::state & (GS_PAUSED | GS_SYNC_WAIT)) == GS_PAUSED)) {
 
@@ -358,7 +374,8 @@ void Displayer::displayPlay (   )
     LightManager::resetHeadLight();
   }
 
-  glDisable(GL_LIGHTING);
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+    glDisable(GL_LIGHTING);
   glDisable(GL_COLOR_MATERIAL);
 
   glEnable(GL_BLEND);
@@ -366,11 +383,12 @@ void Displayer::displayPlay (   )
 
   glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_BLEND);
 
-  drawWinRecord();
-
-  // calls glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE)
-  // internally
-  drawCandy();
+  if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS)) {
+    drawWinRecord();
+    // calls glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE)
+    // internally
+    drawCandy();
+  }
 
   if (!(Game::state & GS_PAUSED))
     drawCountDown();
@@ -413,7 +431,7 @@ void Displayer::screenShot (   )
   ostringstream file_name;
   file_name << DC_SCREEN_SHOT_FILE_NAME_BASE "_" << setw(GC_GARBAGE_TEX_NUMBER_DIGITS)
    << setfill('0') << count << ".tga" << ends;
-  TextureLoader::createTGA(file_name.str(), image, screen_length, screen_length,
+  TextureLoader::createTGA(file_name.str().c_str(), image, screen_length, screen_length,
    TL_SCREEN_SHOT_TGA_ID);
 
   MESSAGE("creating " << file_name.str());
