@@ -33,6 +33,8 @@
 #  include <glext.h>
 #endif
 
+#include <sys/time.h>
+
 using namespace std;
 
 #include "Game.h"
@@ -61,6 +63,7 @@ using namespace std;
 #include "Swapper.h"
 #include "WinRecord.h"
 #include "X.h"
+#include "ComputerPlayer.h"
 
 int Game::time_step;
 int Game::state;
@@ -72,6 +75,7 @@ int Game::remaining_time;
 bool Game::button_down_pause;
 bool Game::step_play;
 int Game::sync_wait;
+double Game::lastframe = 0.0;
 
 void Game::initialize (   )
 {
@@ -108,6 +112,7 @@ void Game::gameStart (   )
   CountDownManager::gameStart();
   Clock::gameStart();
   LoseBar::gameStart();
+	ComputerPlayer::gameStart();
 
   button_down_pause = false;
 
@@ -153,6 +158,12 @@ void Game::lossConfirmation (   )
   state = GS_LOST | GS_END_PLAY;
 }
 
+void Game::aiPlayerLoss (   )
+{
+  if (!(state & GS_WON) && !(state & GS_END_PLAY))
+    state = GS_WON | GS_END_PLAY;
+}
+
 void Game::won (   )
 /*
  * Called by Communicator when opponent signals a game loss that predates
@@ -253,6 +264,19 @@ void Game::syncUnpause (   )
 
 void Game::idleMeta (   )
 {
+  timeval now;
+  double nowd;
+  gettimeofday(&now,NULL);
+  #define FPSDIFF (1.0f/30.0f)
+  nowd = now.tv_sec;
+  nowd += (double)now.tv_usec / 1000000.0f;
+
+  if ( (nowd - lastframe) > FPSDIFF ) {
+    lastframe = nowd;
+  } else {
+    usleep(1000);
+  }
+
   int modified_and_complete = false;
 
   do {
@@ -289,7 +313,8 @@ void Game::idleMeta (   )
     // update the pretty stuff too
     SparkleManager::timeStep();
     SignManager::timeStep();
-    WinRecord::timeStep();
+    if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+      WinRecord::timeStep();
     LevelLights::timeStep();
 
     // advance the clock through its final tick fade
@@ -308,6 +333,19 @@ void Game::idleMeta (   )
 
 void Game::idlePlay (   )
 {
+  timeval now;
+  double nowd;
+  gettimeofday(&now,NULL);
+  #define FPSDIFF (1.0f/30.0f)
+  nowd = now.tv_sec;
+  nowd += (double)now.tv_usec / 1000000.0f;
+
+  if ( (nowd - lastframe) > FPSDIFF ) {
+    lastframe = nowd;
+  } else {
+    usleep(1000);
+  }
+
   int modified_and_complete = false;
 
   do {
@@ -357,6 +395,9 @@ void Game::idlePlay (   )
           continue;
         }
 
+				if (MetaState::mode & CM_AI) 
+					ComputerPlayer::timeStep();
+
         // loop over the grid, bottom to top; garbage will advance x and y
         for (int y = 1; y < GC_PLAY_HEIGHT; y++)
           for (int x = 0; x < GC_PLAY_WIDTH; x++) {
@@ -392,7 +433,8 @@ void Game::idlePlay (   )
         SignManager::timeStep();
 
         // update the impact spring
-        Spring::timeStep();
+        if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+          Spring::timeStep();
 
         // update the clock
         Clock::timeStepPlay();
@@ -426,12 +468,16 @@ void Game::idlePlay (   )
       step_play = false;
 
     if (state & GS_END_PLAY) {
+      // step_play = false;
       if (state & GS_PAUSED)
         MessageManager::freeMessage();
 
-      if (MetaState::mode & CM_SOLO)
+      if ((MetaState::mode & CM_SOLO) && !(MetaState::mode & CM_AI))
         state = Score::gameFinish();
 
+      if (MetaState::mode & CM_AI)
+        state = ComputerPlayer::gameFinish();
+
       if (state & GS_LOST)
         MetaState::gameLoss();
       else
