@@ -1,3 +1,29 @@
+/*
+ * Game.h
+ * Daniel Nelson - 8/24/0
+ *
+ * Copyright (C) 2000  Daniel Nelson
+ * Copyright (C) 2004  Andrew Sayman
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ * Daniel Nelson - aluminumangel.org
+ * 174 W. 18th Ave.
+ * Columbus, OH  43210
+ */
+
 #ifndef GAME_H
 #define GAME_H
 
@@ -5,6 +31,7 @@
 #include <cstdlib>
 #include <cmath>
 #include <iostream>
+#include <vector>
 #include <GL/glut.h>
 
 #ifndef _WIN32
@@ -13,6 +40,8 @@
 #  include <glext.h>
 #endif
 
+#include "Mode.h"
+
 using namespace std;
 
 // null
@@ -25,12 +54,10 @@ using namespace std;
 // the name
 #define GC_NAME                          "Crack Attack!"
 #define GC_BINARY                        "crack-attack"
-#define GC_VERSION                       "1.1.9"
+#define GC_VERSION                       "1.1.12"
 
 // startup message
-#define GC_MESSAGE                       GC_NAME " v" GC_VERSION "\n" \
-                                          "  by Daniel Nelson " \
-                                          "[aluminumangel.org], 2002"
+#define GC_MESSAGE                       GC_NAME " v" GC_VERSION "\n"
 
 // directory delimiter
 #ifndef _WIN32
@@ -82,14 +109,6 @@ using namespace std;
 #define GC_REC_FILE_NAME                 "score_record"
 #define GC_DEFAULT_REC_FILE_NAME         GC_DATA_DIRECTORY "default_record"
 
-// meta game modes
-#define CM_SERVER                        (1 << 0)
-#define CM_CLIENT                        (1 << 1)
-#define CM_SOLO                          (1 << 2)
-#define CM_X                             (1 << 3)
-#define CM_NO_TIME_OUT                   (1 << 4)
-#define CM_LOW_GRAPHICS                  (1 << 5)
-
 // random angle tables' size; must be power of two
 #define GC_SIZE_RANDOM_ANGLE_TABLE       (256)
 
@@ -218,6 +237,13 @@ using namespace std;
 #define GC_ADVANCE_KEY                   ('l')
 #define GC_PAUSE_KEY                     ('p')
 
+// Constants for the game window height and width.
+#define GC_RESOLUTION_0                  (400)
+#define GC_RESOLUTION_1                  (570)
+#define GC_RESOLUTION_2                  (680)
+#define GC_RESOLUTION_3                  (970)
+#define GC_RESOLUTION_4                  (1170)
+
 // other crap
 #ifndef max
 #  define max(a, b)                      ((a) > (b) ? (a) : (b))
@@ -348,6 +374,7 @@ public:
 
   static void loss (   );
   static void lossConfirmation (   );
+  static void aiPlayerLoss (   );
   static void won (   );
   static void netSignalPause (   );
   static void netSignalUnpause (   );
@@ -389,6 +416,7 @@ private:
   static bool button_down_pause;
   static bool step_play;
   static int sync_wait;
+  static double lastframe;
 };
 
 #endif
