@@ -35,6 +35,8 @@
 #include "Random.h"
 #include "X.h"
 
+#include <cassert>
+
 using namespace std;
 
 void Garbage::initializeStatic ( int _x, int _y, int _height, int _width,
@@ -63,6 +65,7 @@ void Garbage::initializeStatic ( int _x, int _y, int _height, int _width,
 void Garbage::initializeFalling ( int _x, int _y, int _height, int _width,
  int _flavor )
 {
+  //MESSAGE("Entering initialize Falling _x " << _x << " _y " << _y << " _height " << _height << " _width " << _width);
   x = _x;
   y = _y;
   height = _height;
@@ -70,17 +73,20 @@ void Garbage::initializeFalling ( int _x, int _y, int _height, int _width,
   flavor = _flavor;
   f_y = 0;
 
+  //MESSAGE("Second block start");
   state = GS_FALLING;
   alarm = Game::time_step + GC_HANG_DELAY;
   pop_alarm = 0;
   sections_popped = 0;
   initial_fall = true;
-  awaking_combo = null;
+  awaking_combo = NULL;
 
+  //MESSAGE("Add us to the grid height: " << height << " width " << width);
   // add ourselves to the grid
   for (int h = height; h--; )
     for (int w = width; w--; )
       Grid::addGarbage(x + w, y + h, this, GR_FALLING);
+  //MESSAGE("Out and alive!");
 }
 
 void Garbage::initializeAwaking ( int _x, int _y, int _height, int pop_delay,
@@ -242,7 +248,8 @@ void Garbage::timeStep ( int &l_x, int &l_y )
           // if this is the end of our initial fall
           if (initial_fall) {
             initial_fall = false;
-            Spring::notifyImpact(height, width);
+            if (!(MetaState::mode & CM_REALLY_LOW_GRAPHICS))
+              Spring::notifyImpact(height, width);
             Grid::notifyImpact(y, height);
 
             X::notifyImpact(*this);
