@@ -63,7 +63,7 @@ create_winCrackAttackSplash (void)
   GtkWidget *vbox5;
   GtkWidget *label4;
   GtkWidget *entPlayerName;
-  GtkWidget *cbtnLowGraphics;
+  GtkWidget *cbtnLowGraphics, *cbtnReallyLowGraphics;
   GtkWidget *alignment1;
   GtkWidget *vbox2;
   GtkWidget *hbox8;
@@ -81,8 +81,8 @@ create_winCrackAttackSplash (void)
   GtkWidget *fraSingle;
   GtkWidget *vbox8;
   GtkWidget *hbox9;
-  //GtkWidget *lblComputer;
-  //GtkWidget *optionmenu1;
+  GtkWidget *lblComputer;
+  GtkWidget *optionmenu1;
   GtkWidget *menu2;
   GtkWidget *ai_none;
   GtkWidget *image2;
@@ -150,8 +150,13 @@ create_winCrackAttackSplash (void)
   gtk_entry_set_text (GTK_ENTRY (entPlayerName), g_get_user_name());
 
   cbtnLowGraphics = gtk_check_button_new_with_mnemonic ("Reduced Graphics Mode");
+  cbtnReallyLowGraphics = gtk_check_button_new_with_mnemonic("Extremely Reduced Graphics Mode");
+
   gtk_widget_show (cbtnLowGraphics);
+  gtk_widget_show (cbtnReallyLowGraphics);
   gtk_box_pack_start (GTK_BOX (vbox5), cbtnLowGraphics, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox5), cbtnReallyLowGraphics, FALSE, FALSE, 0);
+
 
   alignment1 = gtk_alignment_new (0.5, 0.5, 1, 1);
   gtk_widget_show (alignment1);
@@ -222,7 +227,6 @@ create_winCrackAttackSplash (void)
   gtk_widget_show (hbox9);
   gtk_box_pack_start (GTK_BOX (vbox8), hbox9, FALSE, FALSE, 0);
 
-  /*
   lblComputer = gtk_label_new ("Computer AI:");
   gtk_widget_show (lblComputer);
   gtk_box_pack_start (GTK_BOX (hbox9), lblComputer, FALSE, FALSE, 5);
@@ -266,7 +270,6 @@ create_winCrackAttackSplash (void)
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (ai_hard), image5);
 
   gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu1), menu2);
-  */
 
   cbtnXtreme = gtk_check_button_new_with_mnemonic ("X-treme");
   gtk_widget_show (cbtnXtreme);
@@ -404,6 +407,9 @@ create_winCrackAttackSplash (void)
   g_signal_connect ((gpointer) cbtnLowGraphics, "toggled",
                     G_CALLBACK (on_cbtnLowGraphics_toggled),
                     NULL);
+  g_signal_connect ((gpointer) cbtnReallyLowGraphics, "toggled",
+                    G_CALLBACK (on_cbtnReallyLowGraphics_toggled),
+                    NULL);
   g_signal_connect ((gpointer) _640by480, "activate",
                     G_CALLBACK (on_640by480_activate),
                     NULL);
@@ -422,7 +428,6 @@ create_winCrackAttackSplash (void)
   g_signal_connect_after ((gpointer) rbtnSingle, "toggled",
                           G_CALLBACK (on_rbtnSingle_toggled),
                           NULL);
-  /*
   g_signal_connect ((gpointer) ai_none, "activate",
                     G_CALLBACK (on_ai_none_activate),
                     NULL);
@@ -435,7 +440,6 @@ create_winCrackAttackSplash (void)
   g_signal_connect ((gpointer) ai_hard, "activate",
                     G_CALLBACK (on_ai_hard_activate),
                     NULL);
-  */
   g_signal_connect ((gpointer) cbtnXtreme, "toggled",
                     G_CALLBACK (on_Xtreme_toggled),
                     NULL);
@@ -467,6 +471,7 @@ create_winCrackAttackSplash (void)
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, label4, "label4");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, entPlayerName, "entPlayerName");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, cbtnLowGraphics, "cbtnLowGraphics");
+  GLADE_HOOKUP_OBJECT (winCrackAttackSplash, cbtnReallyLowGraphics, "cbtnReallyLowGraphics");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, alignment1, "alignment1");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, vbox2, "vbox2");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, hbox8, "hbox8");
@@ -483,7 +488,6 @@ create_winCrackAttackSplash (void)
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, fraSingle, "fraSingle");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, vbox8, "vbox8");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, hbox9, "hbox9");
-  /*
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, lblComputer, "lblComputer");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, optionmenu1, "optionmenu1");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, menu2, "menu2");
@@ -495,7 +499,6 @@ create_winCrackAttackSplash (void)
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, image4, "image4");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, ai_hard, "ai_hard");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, image5, "image5");
-  */
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, cbtnXtreme, "cbtnXtreme");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, hbox3, "hbox3");
   GLADE_HOOKUP_OBJECT (winCrackAttackSplash, rbtnServer, "rbtnServer");
