@@ -3,6 +3,7 @@
  * Daniel Nelson - 10/1/0
  *
  * Copyright (C) 2000  Daniel Nelson
+ * Copyright (C) 2004  Andrew Sayman
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,8 +27,10 @@
  */
 
 #define GL_GLEXT_LEGACY
+#define GL_GLEXT_PROTOTYPES
 
 #include <GL/glut.h>
+#include <GL/glext.h>
 
 #ifndef _WIN32
 #else
@@ -36,9 +39,9 @@
 
 using namespace std;
 
+#include "TextureLoader.h"
 #include "Game.h"
 #include "Displayer.h"
-#include "TextureLoader.h"
 #include "GarbageFlavorImage.h"
 #include "MetaState.h"
 #include "Random.h"
